@@ -48,7 +48,7 @@
  * ======================
  */
 
-static void poppler_error_handler(void *data, ErrorCategory category, pdf::Offset pos, char *message)
+static void poppler_error_handler(void *data, ErrorCategory category, pdf::Offset pos, const char *message)
 {
   std::string format;
   const char *category_name = _("PDF error");
@@ -94,6 +94,13 @@ static void poppler_error_handler(void *data, ErrorCategory category, pdf::Offse
   error_log << std::endl;
 }
 
+#if POPPLER_VERSION < 7000
+static void poppler_error_handler(void *data, ErrorCategory category, pdf::Offset pos, char *message)
+{
+  poppler_error_handler(data, category, pos, const_cast<const char *>(message));
+}
+#endif
+
 pdf::Environment::Environment()
 {
   globalParams = new GlobalParams();
@@ -153,7 +160,7 @@ static void cmyk_to_rgb(const double cmyk[], double rgb[])
   rgb[2] = pdf::gfx::color_component_as_double(rgb_cc.b);
 }
 
-static pdf::Bool annotations_callback(pdf::ant::Annotation *annotation, void *user_data)
+static bool annotations_callback(pdf::ant::Annotation *annotation, void *user_data)
 {
   std::vector<std::string> &border_colors = *reinterpret_cast<std::vector<std::string>*>(user_data);
   std::string border_color;
@@ -215,7 +222,7 @@ void pdf::Document::get_page_size(int n, bool crop, double &width, double &heigh
 
 const std::string pdf::Document::get_xmp()
 {
-  std::unique_ptr<pdf::String> mstring;
+  std::unique_ptr<const pdf::String> mstring;
   mstring.reset(this->readMetadata());
   if (mstring.get() == nullptr)
     return "";
@@ -537,7 +544,7 @@ double pdf::get_path_area(splash::Path &path)
   double area = 0.0;
   int path_len = path.getLength();
   double x0, y0;
-  Guchar ch;
+  unsigned char ch;
   path.getPoint(0, &x0, &y0, &ch);
   for (int i = 0; i < path_len - 1; i++)
   {
